Class: Fastlane::Actions::FirebaseTestLabAndroidAction
- Inherits:
-
Action
- Object
- Action
- Fastlane::Actions::FirebaseTestLabAndroidAction
- Defined in:
- lib/fastlane/plugin/firebase_test_lab_integration/actions/firebase_test_lab_android.rb
Class Method Summary collapse
-
.authors ⇒ Object
This method is called by fastlane to display plugin authors.
- .available_options ⇒ Object
-
.description ⇒ Object
This method is called by fastlane to display plugin information.
- .details ⇒ Object
- .is_supported?(platform) ⇒ Boolean
- .return_value ⇒ Object
-
.run(params) ⇒ Object
This method is called by fastlane integration as entrypoint of plugin action It is responsible for calling the actual action logic and handling any errors.
Class Method Details
.authors ⇒ Object
This method is called by fastlane to display plugin authors
27 28 29 |
# File 'lib/fastlane/plugin/firebase_test_lab_integration/actions/firebase_test_lab_android.rb', line 27 def self. ::FirebaseTestLabIntegration::Helper::Options. end |
.available_options ⇒ Object
39 40 41 |
# File 'lib/fastlane/plugin/firebase_test_lab_integration/actions/firebase_test_lab_android.rb', line 39 def self. ::FirebaseTestLabIntegration::Helper::Options. end |
.description ⇒ Object
This method is called by fastlane to display plugin information
22 23 24 |
# File 'lib/fastlane/plugin/firebase_test_lab_integration/actions/firebase_test_lab_android.rb', line 22 def self.description ::FirebaseTestLabIntegration::Helper::Options.description("Android") end |
.details ⇒ Object
35 36 37 |
# File 'lib/fastlane/plugin/firebase_test_lab_integration/actions/firebase_test_lab_android.rb', line 35 def self.details ::FirebaseTestLabIntegration::Helper::Options.details end |
.is_supported?(platform) ⇒ Boolean
43 44 45 |
# File 'lib/fastlane/plugin/firebase_test_lab_integration/actions/firebase_test_lab_android.rb', line 43 def self.is_supported?(platform) [:android].include?(platform) end |
.return_value ⇒ Object
31 32 33 |
# File 'lib/fastlane/plugin/firebase_test_lab_integration/actions/firebase_test_lab_android.rb', line 31 def self.return_value # If your method provides a return value, you can describe here what it does end |
.run(params) ⇒ Object
This method is called by fastlane integration as entrypoint of plugin action It is responsible for calling the actual action logic and handling any errors
14 15 16 17 18 19 |
# File 'lib/fastlane/plugin/firebase_test_lab_integration/actions/firebase_test_lab_android.rb', line 14 def self.run(params) FastlaneCore::UI.("Starting Firebase Test Lab Integration for Android.") integration_helper = ::FirebaseTestLabIntegration::Helper::IntegrationHelper.new(:android) integration_helper.run(params) FastlaneCore::UI.("Completed Firebase Test Lab Integration for Android.") end |